@@ -2,8 +2,7 @@
 #'
 #' @param fn [\code{\link[soobench]{soo_function}}]\cr
 #'   Source function.
-#' @return [\code{\link[ParamHelpers]{ParamSet}}]
-#'   Parameter set of type \code{\link[ParamHelpers]{ParamSet}}.
+#' @return [\code{\link{ParamSet}}]
 #' @export
 
 # FIXME: example disabled because of annying soobench interface change
@@ -15,10 +14,10 @@
 extractParamSetFromSooFunction = function(fn) {
   assertClass(fn, "soo_function")
   makeNumericParamSet(
-    len = number_of_parameters(fn),
+    len = soobench::number_of_parameters(fn),
     id = "x",
-    lower = lower_bounds(fn),
-    upper = upper_bounds(fn),
+    lower = soobench::lower_bounds(fn),
+    upper = soobench::upper_bounds(fn),
     vector = FALSE
   )
 }
