@@ -22,6 +22,11 @@
 #'    grid design, but the way parameter dependencies are handled make this possible.}
 #' }
 #'
+#' \code{generateDesign} will NOT work if there are dependencies over multiple levels of
+#' parameters and the dependency is only given with respect to the \dQuote{previous} parameter.
+#' A current workaround is to state all dependencies on all parameters involved.
+#' (We are working on it.)
+#'
 #' @template arg_parset
 #' @param resolution [\code{integer}]\cr
 #'   Resolution of the grid for each numeric/integer parameter in \code{par.set}.
@@ -37,7 +42,6 @@
 #' )
 #' generateGridDesign(ps, resolution = c(x1 = 4, x2 = 5), trafo = TRUE)
 generateGridDesign = function(par.set, resolution, trafo = FALSE) {
-
   z = doBasicGenDesignChecks(par.set)
 
   ids = getParamIds(par.set)
@@ -47,18 +51,18 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
   m = sum(lens)
   pids1 = getParamIds(par.set)
   pids2 = getParamIds(par.set, repeated = TRUE, with.nr = TRUE)
+  par.set.num = filterParams(par.set = par.set, type = getNumericTypes())
+  pids.num = getParamIds(par.set.num)
 
-  if (length(resolution) == 1L) {
-    resolution = setNames(rep(resolution, n), pids1)
+  if (hasNumeric(par.set, include.int = TRUE)) {
+    if (isScalarNumeric(resolution)) {
+      resolution = setNames(rep(resolution, length(pids.num)), pids.num)
+    }
+    resolution = asInteger(resolution, lower = 1L, len = length(pids.num))
+    assertNamed(resolution, type = "named")
+    if (!all(names(resolution) %in% pids.num))
+      stop("'resolution' must be named with parameter ids!")
   }
-  #FIXME: cm removes namesm bug
-  ns = names(resolution)
-  resolution = asInteger(resolution, lower = 1L, len = n)
-  names(resolution) = ns
-  assertNamed(resolution, type = "named")
-  if (!all(names(resolution) == pids1))
-    stop("'resolution' must be named with parameter ids!")
-  resolution = resolution[pids1]
 
   assertFlag(trafo)
 
@@ -69,7 +73,6 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
   for (i in 1:n) {
     p = pars[[i]]
     type = p$type
-    reso = resolution[[i]]
     if (isNumeric(p)) {
       lower = p$lower
       upper = p$upper
@@ -85,7 +88,7 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
       } else if (isLogical(p)) {
         newvals = c(TRUE, FALSE)
       } else if (isNumeric(p, include.int = TRUE)) {
-        newvals = seq(from = lower[[j]], to = upper[[j]], length.out = reso)
+        newvals = seq(from = lower[[j]], to = upper[[j]], length.out = resolution[[p$id]])
         # round for integer
         if (isInteger(p)) {
           newvals = as.integer(unique(round(newvals)))
@@ -132,5 +135,5 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
 
   res = convertDataFrameCols(res, chars.as.factor = TRUE)
   attr(res, "trafo") = trafo
-  res
+  return(res)
 }
