@@ -14,13 +14,17 @@
 #'
 #' The algorithm simply calls \code{\link{sampleValues}} and arranges the result in a data.frame.
 #'
+#' \code{generateRandomDesign} will NOT work if there are dependencies over multiple levels of
+#' parameters and the dependency is only given with respect to the \dQuote{previous} parameter.
+#' A current workaround is to state all dependencies on all parameters involved.
+#' (We are working on it.)
+#'
 #' @template arg_gendes_n
 #' @template arg_parset
 #' @template arg_trafo
 #' @template ret_gendes_df
 #' @export
 generateRandomDesign = function(n = 10L, par.set, trafo = FALSE) {
-
   z = doBasicGenDesignChecks(par.set)
   pids = getParamIds(par.set, repeated = TRUE, with.nr = TRUE)
 
@@ -39,7 +43,7 @@ generateRandomDesign = function(n = 10L, par.set, trafo = FALSE) {
   des = lapply(des, elementsToDf)
   des = lapply(des, do.call, what = cbind)
   des = do.call(rbind, des)
-  setColNames(des, pids)
+  return(setColNames(des, pids))
 }
 
 
